PySqueezeCenter Documentation — PySqueezeCenter v0.91 documentation

### Navigation

- index
- next |
- PySqueezeCenter v0.91 documentation »

# PySqueezeCenter Documentation

PySqueezeCenter is a Python wrapper library for communication with a Logitech SqueezeCenter CLI (Telnet) interface. Once connected, it is possible to control the server and any compatible Logitech SqueezeBox devices associated with it.

Contents:

- Server Class (pysqueezecenter.player.Server)
- Player Class (pysqueezecenter.player.Player)
- Command Line Utility

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- PySqueezeCenter v0.91 documentation »